@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.052';
+$VERSION = '0.053';
 
 no warnings 'uninitialized';
 
@@ -49,10 +49,19 @@ sub _init {
 sub cron {
     my( $self, $data, $acct ) = @_;
     if( $acct->is_root() ) {
-	return $self->get__crond();
+	return $self->_cron();
     }
     die "Permissions Error";
 } #cron
+sub _cron {
+    my $self = shift;
+    my $c = $self->get__crond();
+    unless( $c ) {
+	$c = new Yote::Cron();
+	$self->set__crond( $c );
+    }
+    return $c;
+}
 
 sub disable_account {
     my( $self, $account_to_be_disabled, $logged_in_account ) = @_;
@@ -259,6 +268,13 @@ sub remove_root {
     return;
 } #remove_root
 
+#
+# Resets the cron, emptying it with the default items
+#
+sub reset_cron {
+    my( $self, $data, $acct ) = @_;
+    $self->set__crond( new Yote::Cron() );
+} #reset_cron
 
 # ------------------------------------------------------------------------------------------
 #      * PRIVATE METHODS *
@@ -492,15 +508,14 @@ Returns a new user yote object, initialized with the optional has reference.
 
 This method may only be invoked by a login with the root bit set. This clears out the app entirely.
 
-=item recover_password( { e : email, u : a_url_the_person_requested_recovery, t : reset_url_for_system } )
-
-Causes an email with a recovery link sent to the email in question, if it is associated with an account.
-
-
 =item remove_root( login )
 
 Removes the root bit from the login.
 
+=item reset_cron
+
+Removes and rebuilds the cron.
+
 =back
 
 =head1 PRIVATE DATA FIELDS
